===============================
Montague
===============================

.. image:: http://img.shields.io/travis/inklesspen/montague/master.png?style=flat
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/inklesspen/montague

.. image:: https://ci.appveyor.com/api/projects/status/github/inklesspen/montague?branch=master
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/inklesspen/montague

.. image:: http://img.shields.io/coveralls/inklesspen/montague/master.png?style=flat
    :alt: Coverage Status
    :target: https://coveralls.io/r/inklesspen/montague

.. image:: http://img.shields.io/pypi/v/montague.png?style=flat
    :alt: PYPI Package
    :target: https://pypi.python.org/pypi/montague

.. image:: http://img.shields.io/pypi/dm/montague.png?style=flat
    :alt: PYPI Package
    :target: https://pypi.python.org/pypi/montague

.. image:: https://landscape.io/github/inklesspen/montague/master/landscape.png?style=flat
    :target: https://landscape.io/github/inklesspen/montague/master
    :alt: Code Quality Status

.. image:: https://readthedocs.org/projects/montague/badge/?style=flat
    :target: https://readthedocs.org/projects/montague
    :alt: Documentation Status

Montague provides functions to load WSGI apps and servers based on configuration files.
          
* Free software: MIT license

Status
======

Montague is a pre-1.0 project using Semantic Versioning.

Installation
============

::

    pip install montague

Documentation
=============

https://montague.readthedocs.org/

Development
===========

To run the all tests run::

    tox
